==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Strona g&#322;&oacute;wna',
'articles' => 'Artyku&#322;y',
'articles_auteur' => 'Artyku&#322;y napisane przez tego autora',
'articles_populaires' => 'Najbardziej popularne artyku&#322;y',
'articles_rubrique' => 'Artyku&#322;y w tym dziale',
'aucun_article' => 'Nie ma &#380;adnego artyku&#322;u pod tym adresem',
'aucun_auteur' => 'Nie ma &#380;adnego autora pod tym adresem',
'aucun_site' => 'Nie ma &#380;adnej strony pod tym adresem',
'aucune_breve' => 'Nie ma &#380;adnego newsa pod tym adresem ',
'aucune_rubrique' => 'Nie ma &#380;adnego dzia&#322;u pod tym adresem',
'autres_breves' => 'Reszta aktualno&#347;ci',
'autres_groupes_mots_clefs' => 'Inne grupy s&#322;&oacute;w kluczowych',
'autres_sites' => 'Inne strony',

// B
'bonjour' => 'Dzie&#324; dobry',
'breves' => 'Aktualno&#347;ci',

// C
'commenter_site' => 'Dodaj komentarz na temat strony',

// D
'date' => 'Data',
'dernier_ajout' => 'Dodane ostatnio',
'dernieres_breves' => 'Najnowsze aktualno&#347;ci',
'derniers_articles' => 'Najnowsze artyku&#322;y',
'derniers_commentaires' => 'Ostatnie komentarze',
'derniers_messages_forum' => 'Ostatnie wiadomo&#347;ci opublikowane w forum',

// E
'edition_mode_texte' => 'Edycja w trybie tekstowym',
'en_reponse' => 'W odpowiedzi na&nbsp;:',
'en_resume' => 'W skr&oacute;cie',
'envoyer_message' => 'Wy&#347;lij wiadomo&#347;&#263;',
'espace_prive' => 'Strefa prywatna',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Mapa strony',

// J
'jours' => 'dni',

// M
'meme_auteur' => 'Ten sam autor',
'meme_rubrique' => 'W tym samym dziale',
'memes_auteurs' => 'Tych samych autor&oacute;w',
'message' => 'Wiadomo&#347;&#263;',
'messages_forum' => 'Wiadomo&#347;ci na forum',
'messages_recents' => 'Najnowsze wiadomo&#347;ci na forum',
'mots_clefs' => 'S&#322;owa kluczowe',
'mots_clefs_meme_groupe' => 'S&#322;owa kluczowe z tej samej grupy',

// N
'navigation' => 'Nawigacja',
'nom' => 'Nazwisko',
'nouveautes' => 'Nowo&#347;ci',
'nouveautes_web' => 'Nowo&#347;ci w Internecie',
'nouveaux_articles' => 'NOwe artyku&#322;y',
'nouvelles_breves' => 'Najnowsze aktualno&#347;ci',

// P
'page_precedente' => 'poprzednia strona',
'page_suivante' => 'nast&#281;pna strona',
'par_auteur' => 'przez',
'participer_site' => 'Mo&#380;esz wzi&#261;&#263; udzia&#322; w tworzeniu tego serwisu i proponowa&#263; w&#322;asne artyku&#322;y. Aby mie&#263; tak&#261; mo&#380;liwo&#347;&#263;, musisz si&#281; zapisa&#263; poni&#380;ej. Na podany adres e-mail otrzymasz has&#322;o dost&#281;pu do strefy prywatnej serwisu.',
'plan_site' => 'Mapa strony',
'popularite' => 'Popularno&#347;&#263;',
'poster_message' => 'Napisz wiadomo&#347;&#263;',
'proposer_site' => 'Mo&#380;es zaproponowa&#263; stron&#281; do dodania w tym katalogu:',

// R
'repondre_article' => 'Skomentuj ten artyku&#322;',
'repondre_breve' => 'Skomentuj ten news',
'repondre_message' => 'Skomentuj wiadomo&#347;&#263;',
'resultats_recherche' => 'Wynik wyszukiwania',
'retour_debut_forums' => 'Powr&oacute;t do strony g&#322;&oacute;wnej forum',
'rubrique' => 'Dzia&#322;',
'rubriques' => 'Dzia&#322;y',

// S
'signatures_petition' => 'Podpisy',
'site_realise_avec_spip' => 'Strona zrealizowana przy pomocy SPIP',
'sites_web' => 'Strony internetowe',
'sous_rubriques' => 'Pod-dzia&#322;y',
'suite' => 'wi&#281;cej',
'sur_web' => 'W internecie',
'syndiquer_rubrique' => 'Ten dzia&#322;',
'syndiquer_site' => 'Ca&#322;&#261; stron&#281;',

// T
'texte_lettre_information' => 'Poni&#380;ej lista subskrypcyjna serwisu',
'texte_lettre_information_2' => 'Na tej li&#347;cie znajdziesz archiwum artyku&#322;&oacute;w i aktualno&#347;ci opublikowanych od',

// V
'ver_imprimer' => 'Wersja do druku',
'voir_en_ligne' => 'Zobacz on-line',
'voir_squelette' => 'zobacz szkielet/template strony'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Strona g&#322;&oacute;wna',
'article' => 'Article', # NEW
'articles' => 'Artyku&#322;y',
'articles_auteur' => 'Artyku&#322;y napisane przez tego autora',
'articles_populaires' => 'Najbardziej popularne artyku&#322;y',
'articles_rubrique' => 'Artyku&#322;y w tym dziale',
'aucun_article' => 'Nie ma &#380;adnego artyku&#322;u pod tym adresem',
'aucun_auteur' => 'Nie ma &#380;adnego autora pod tym adresem',
'aucun_site' => 'Nie ma &#380;adnej strony pod tym adresem',
'aucune_breve' => 'Nie ma &#380;adnego newsa pod tym adresem ',
'aucune_rubrique' => 'Nie ma &#380;adnego dzia&#322;u pod tym adresem',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Reszta aktualno&#347;ci',
'autres_groupes_mots_clefs' => 'Inne grupy s&#322;&oacute;w kluczowych',
'autres_sites' => 'Inne strony',

// B
'bonjour' => 'Dzie&#324; dobry',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Aktualno&#347;ci',

// C
'commenter_site' => 'Dodaj komentarz na temat strony',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => 'Dodane ostatnio',
'dernieres_breves' => 'Najnowsze aktualno&#347;ci',
'derniers_articles' => 'Najnowsze artyku&#322;y',
'derniers_commentaires' => 'Ostatnie komentarze',
'derniers_messages_forum' => 'Ostatnie wiadomo&#347;ci opublikowane w forum',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edycja w trybie tekstowym',
'en_reponse' => 'W odpowiedzi na&nbsp;:',
'en_resume' => 'W skr&oacute;cie',
'envoyer_message' => 'Wy&#347;lij wiadomo&#347;&#263;',
'espace_prive' => 'Strefa prywatna',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Mapa strony',

// J
'jours' => 'dni',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Ten sam autor',
'meme_rubrique' => 'W tym samym dziale',
'memes_auteurs' => 'Tych samych autor&oacute;w',
'message' => 'Wiadomo&#347;&#263;',
'messages_forum' => 'Wiadomo&#347;ci na forum',
'messages_recents' => 'Najnowsze wiadomo&#347;ci na forum',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'S&#322;owa kluczowe',
'mots_clefs_meme_groupe' => 'S&#322;owa kluczowe z tej samej grupy',

// N
'navigation' => 'Nawigacja',
'nom' => 'Nazwisko',
'nouveautes' => 'Nowo&#347;ci',
'nouveautes_web' => 'Nowo&#347;ci w Internecie',
'nouveaux_articles' => 'NOwe artyku&#322;y',
'nouvelles_breves' => 'Najnowsze aktualno&#347;ci',

// P
'page_precedente' => 'poprzednia strona',
'page_suivante' => 'nast&#281;pna strona',
'par_auteur' => 'przez',
'participer_site' => 'Mo&#380;esz wzi&#261;&#263; udzia&#322; w tworzeniu tego serwisu i proponowa&#263; w&#322;asne artyku&#322;y. Aby mie&#263; tak&#261; mo&#380;liwo&#347;&#263;, musisz si&#281; zapisa&#263; poni&#380;ej. Na podany adres e-mail otrzymasz has&#322;o dost&#281;pu do strefy prywatnej serwisu.',
'plan_site' => 'Mapa strony',
'popularite' => 'Popularno&#347;&#263;',
'poster_message' => 'Napisz wiadomo&#347;&#263;',
'proposer_site' => 'Mo&#380;es zaproponowa&#263; stron&#281; do dodania w tym katalogu:',

// R
'repondre_article' => 'Skomentuj ten artyku&#322;',
'repondre_breve' => 'Skomentuj ten news',
'repondre_message' => 'Skomentuj wiadomo&#347;&#263;',
'resultats_recherche' => 'Wynik wyszukiwania',
'retour_debut_forums' => 'Powr&oacute;t do strony g&#322;&oacute;wnej forum',
'rubrique' => 'Dzia&#322;',
'rubriques' => 'Dzia&#322;y',

// S
'signatures_petition' => 'Podpisy',
'site_realise_avec_spip' => 'Strona zrealizowana przy pomocy SPIP',
'sites_web' => 'Strony internetowe',
'sous_rubriques' => 'Pod-dzia&#322;y',
'spam' => 'Spam', # NEW
'suite' => 'wi&#281;cej',
'sur_web' => 'W internecie',
'syndiquer_rubrique' => 'Ten dzia&#322;',
'syndiquer_site' => 'Ca&#322;&#261; stron&#281;',

// T
'texte_lettre_information' => 'Poni&#380;ej lista subskrypcyjna serwisu',
'texte_lettre_information_2' => 'Na tej li&#347;cie znajdziesz archiwum artyku&#322;&oacute;w i aktualno&#347;ci opublikowanych od',

// V
'ver_imprimer' => 'Wersja do druku',
'voir_en_ligne' => 'Zobacz on-line',
'voir_squelette' => 'zobacz szkielet/template strony'
);

?>
